//	Bullet.cpp - Bullet fired from a weapon toadstool.
//  ----------------------------------------------------------------------------
//	This file is part of 'GameTemplate', template code for a game.
//	Copyright (C) 2010  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#include "Bullet.h"
#include "NiallsDrawingLib/Drawer.h"
#include "NiallsDrawingLib/ImageLoader.h"
#include "Images.h"

//------------------------------------------------------------------------------
uint32_t Bullet::image = 0;

//------------------------------------------------------------------------------
Bullet::Bullet(float x, float y, float xD, float yD, float rot):
xPos(x),
yPos(y),
xDir(xD),
yDir(yD),
rotation(rot)
{
	
}

//------------------------------------------------------------------------------
Bullet::~Bullet()
{
	
}

//------------------------------------------------------------------------------
bool Bullet::move()
{
	bool retval = false;
	const float radius = getRadius();

	xPos += xDir * 4.0f;
	yPos += yDir * 4.0f;

	if((xPos < -radius) || (xPos > 1280.0f) ||
	   (yPos < -radius) || (yPos > (800.0f+radius)))
	{
		retval = true;
	}

	return retval;
}

//------------------------------------------------------------------------------
void Bullet::draw(Drawer *d)
{
	if(!image)
	{
		ImageLoader imLoad;
		ImageData data;

		data = imLoad.loadImage(Images::bullet_png, Images::bullet_pngSize);
		image = d->loadImage(data.data, data.width, data.height);
	}

	d->drawImageRot(image, xPos-12.0f, yPos-22.0f, rotation, 12.0f, 22.0f);
}
