//	Fungus.cpp - A fungus.
//  ----------------------------------------------------------------------------
//	This file is part of 'GameTemplate', template code for a game.
//	Copyright (C) 2010  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#include "Fungus.h"
#include "NiallsDrawingLib/Drawer.h"
#include "GamePlay.h"
#include "Random.h"

using namespace std;

//------------------------------------------------------------------------------
int Fungus::maxHealth = 1;
bool Fungus::attacking = false;

//------------------------------------------------------------------------------
Fungus::Fungus(const string& fungusName,
			   uint32_t fungusImage,
			   float w,
			   float h,
			   const vector<BoundingBox>& bounds,
			   float fungusScale):
name(fungusName),
image(fungusImage),
xPos(1280.0f),
width(w),
height(h),
scale(fungusScale),
health(maxHealth),
shootCount(30),
collisionBoxes(bounds),
easyMode(false)
{
	if(scale < 0.0f)
	{
		int i;

		yPos = height + 32.0f;

		for(i=0;i<collisionBoxes.size();++i)
		{
			collisionBoxes[i].y = height - (collisionBoxes[i].y +
											collisionBoxes[i].h);
		}
	}
	else
		yPos = 800.0f-height-32.0f;
}

//------------------------------------------------------------------------------
Fungus::~Fungus()
{
	
}

//------------------------------------------------------------------------------
bool Fungus::move(GamePlay *gp)
{
	bool retval = false;

	xPos -= 1.0f;

	if((xPos+width) < 0.0f)
		retval = true;

	if(attacking)
	{
		--shootCount;
		if(shootCount <= 0)
		{
			if(scale > 0.0f)
				gp->addPinkSpore(xPos+(width*0.5f), yPos+(height*0.5f));
			else
				gp->addPinkSpore(xPos+(width*0.5f), yPos-(height*0.5f));
			shootCount = 75;
			if(easyMode)
				shootCount += 75;
			shootCount += (int)(Random::getGlobal().getRandomFloat() * 29.9999f);
		}
	}

	return retval;
}

//------------------------------------------------------------------------------
void Fungus::draw(Drawer *d)
{
	const float y = getY();

	d->drawImage(image, xPos, yPos, 1.0f, scale);

	if(0)
	{
		for(int i=0;i<collisionBoxes.size();++i)
		{
			d->fillRect(xPos + collisionBoxes[i].x,
						y + collisionBoxes[i].y,
						collisionBoxes[i].w,
						collisionBoxes[i].h,
						255,
						0,
						0,
						128);
		}
	}
}

//------------------------------------------------------------------------------
void Fungus::decrementHealth()
{
	--health;
}

//------------------------------------------------------------------------------
void Fungus::setEasyMode(bool val)
{
	easyMode = val;
}
