//	KeyManager.h - Class used to handle configurable keys.
//  ----------------------------------------------------------------------------
//	This file is part of 'GameTemplate', template code for a game.
//	Copyright (C) 2010  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifndef KEYMANAGER_H_
#define KEYMANAGER_H_

#include "SDL.h"
#include <map>
#include <string>

///	Class used to handle configurable keys.
class KeyManager
{
  public:
	///	Constructor.
	KeyManager();
	///	Destructor.
	~KeyManager();

	enum KeyPress
	{
		KeyNull,
		KeyA,
		KeyB,
		KeyC,
		KeyD,
		KeyE,
		KeyF,
		KeyG,
		KeyH,
		KeyI,
		KeyJ,
		KeyK,
		KeyL,
		KeyM,
		KeyN,
		KeyO,
		KeyP,
		KeyQ,
		KeyR,
		KeyS,
		KeyT,
		KeyU,
		KeyV,
		KeyW,
		KeyX,
		KeyY,
		KeyZ,
		Key0,
		Key1,
		Key2,
		Key3,
		Key4,
		Key5,
		Key6,
		Key7,
		Key8,
		Key9,
		KeyTab,
		KeyShift,
		KeyCtrl,
		KeyAlt,
		KeySpace,
		KeyReturn,
		KeyUp,
		KeyLeft,
		KeyRight,
		KeyDown,
		KeyHome,
		KeyEnd,
		KeyPgUp,
		KeyPgDown,
		KeyNum0,
		KeyNum1,
		KeyNum2,
		KeyNum3,
		KeyNum4,
		KeyNum5,
		KeyNum6,
		KeyNum7,
		KeyNum8,
		KeyNum9,
		KeyMinus,
		KeyEquals,
		KeyBackspace,
		KeyDelete,
		KeyEscape,
		KeyComma,
		KeyPeriod,
		Joy0Up,
		Joy0Left,
		Joy0Right,
		Joy0Down,
		Joy0Button1,
		Joy0Button2,
		Joy0Button3,
		Joy0Button4,
		Joy1Up,
		Joy1Left,
		Joy1Right,
		Joy1Down,
		Joy1Button1,
		Joy1Button2,
		Joy1Button3,
		Joy1Button4,
		Joy2Up,
		Joy2Left,
		Joy2Right,
		Joy2Down,
		Joy2Button1,
		Joy2Button2,
		Joy2Button3,
		Joy2Button4,
		Joy3Up,
		Joy3Left,
		Joy3Right,
		Joy3Down,
		Joy3Button1,
		Joy3Button2,
		Joy3Button3,
		Joy3Button4,
		Joy4Up,
		Joy4Left,
		Joy4Right,
		Joy4Down,
		Joy4Button1,
		Joy4Button2,
		Joy4Button3,
		Joy4Button4
	};

	///	Adds a default keypress.
	void addKeypress(const std::string& name, KeyPress defaultKey);
	///	Loads the user's keyconfig.txt file (creates it if it isn't there).
	void loadConfigFile(const std::string& appName);
	///	Writes the keyconfig.txt from the contents of mappings.
	void saveConfigFile(const std::string& appName);

	///	Returns the action for a particular key press.
	const std::string getAction(KeyPress key);
	///	Returns the action for a particular key press.
	const std::string getAction(const SDL_keysym& keyPressed);
	///	Returns the action for a particular key press.
	/*!
		\param joystick Index of the joystick sending the event.
		\param param What the event relates to. (0 = Up, 1 = Right,
		2 = Down, 3 = Left, 4 = Button1, 5 = Button2, etc.).
	 */
	const std::string getAction(int joystick, int param);
  private:
	///	Helper method, converts KeyPress to a string.
	std::string getKeyPressText(KeyPress key) const;
	///	Helper method, converts a string to a KeyPress.
	KeyPress getKeyPressFromText(const std::string& text) const;

	///	The mappings between KeyPresses and actions.
	std::map<KeyPress, std::string> mappings;
};

#endif
