//	KillerSpore.h - A spore which kills the player on contact.
//  ----------------------------------------------------------------------------
//	This file is part of 'GameTemplate', template code for a game.
//	Copyright (C) 2010  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifndef KILLERSPORE_H_
#define KILLERSPORE_H_

#include <stdint.h>

class Drawer;

///	A spore which kills the player on contact.
class KillerSpore
{
  public:
	///	Constructor.
	KillerSpore();
	///	Destructor.
	~KillerSpore();

	///	Moves the KillerSpore.
	bool move();
	///	Draws the KillerSpore.
	void draw(Drawer *d);

	///	Returns the KillerSpore's position.
	float getX() const {return xPos;};
	///	Returns the KillerSpore's position.
	float getY() const {return yPos;};
	///	Returns the KillerSpore's radius.
	float getRadius() const {return 10.0f;};
  private:
	///	The KillerSpore's image.
	static uint32_t image;

	///	The KillerSpore's position.
	float xPos;
	///	The KillerSpore's position.
	float yPos;
	///	The KillerSpore's speed.
	float speed;
	///	The KillerSpore's position in its sine wave.
	float index;
	///	The speed the KillerSpore moves through its sine wave.
	float increment;
	///	The KillerSpore's baseline y position.
	float yBase;
};

#endif
