//	MusicSingleton.cpp - Singleton class to switch between different tracks.
//  ----------------------------------------------------------------------------
//	This file is part of 'GameTemplate', template code for a game.
//	Copyright (C) 2010  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifdef DEBUG
#pragma warning(disable : 4786) //Stupid MS headers...
#endif

#include "MusicSingleton.h"
#include "BackgroundMusic.h"
#include "FilePath.h"

using namespace std;

//------------------------------------------------------------------------------
MusicSingleton& MusicSingleton::getInstance()
{
	static MusicSingleton retval;

	return retval;
}

//------------------------------------------------------------------------------
void MusicSingleton::addTrack(const string& name)
{
	FilePath minusExtension(name);
	BackgroundMusic *music = new BackgroundMusic();

	music->setSoundFile(name);

	tracks.insert(make_pair(minusExtension.getName(), music));
	if(tracks.size() == 1)
	{
		tracks.begin()->second->start();
		currentTrack = tracks.begin()->first;
	}
}

//------------------------------------------------------------------------------
void MusicSingleton::playTrack(const std::string& name)
{
	map<string, BackgroundMusic *>::iterator it;

	if(name == currentTrack)
		return;

	it = tracks.find(name);
	if(it != tracks.end())
	{
		tracks[currentTrack]->stop();
		tracks[name]->start();
		currentTrack = name;
	}
}

//------------------------------------------------------------------------------
void MusicSingleton::audioBlock(float *buffer, int numSamples)
{
	map<string, BackgroundMusic *>::iterator it;

	if(!isMuted)
	{
		for(it=tracks.begin();it!=tracks.end();++it)
			it->second->audioBlock(buffer, numSamples);
	}
}

//------------------------------------------------------------------------------
void MusicSingleton::mute()
{
	isMuted = !isMuted;
}

//------------------------------------------------------------------------------
MusicSingleton::MusicSingleton():
isMuted(false)
{
	
}

//------------------------------------------------------------------------------
MusicSingleton::~MusicSingleton()
{
	map<string, BackgroundMusic *>::iterator it;

	for(it=tracks.begin();it!=tracks.end();++it)
		delete it->second;
}
