//	StoryScreen.cpp - Explains what you're doing.
//  ----------------------------------------------------------------------------
//	This file is part of 'GameTemplate', template code for a game.
//	Copyright (C) 2010  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#include "StoryScreen.h"
#include "NiallsDrawingLib/Drawer.h"
#include "NiallsDrawingLib/ImageLoader.h"
#include "Images.h"

using namespace std;

//------------------------------------------------------------------------------
uint32_t StoryScreen::back[2] = {0, 0};
uint32_t StoryScreen::font = 0;

//------------------------------------------------------------------------------
StoryScreen::StoryScreen(Application *app, bool easy):
GameState(app),
easyMode(easy)
{
	
}

//------------------------------------------------------------------------------
StoryScreen::~StoryScreen()
{
	
}

//------------------------------------------------------------------------------
void StoryScreen::draw(Drawer *d)
{
	if(!font)
	{
		ImageLoader imLoad;
		ImageData data;

		data = imLoad.loadImage(Images::back1_jpg, Images::back1_jpgSize);
		back[0] = d->loadImage(data.data, data.width, data.height);

		data = imLoad.loadImage(Images::back2_jpg, Images::back2_jpgSize);
		back[1] = d->loadImage(data.data, data.width, data.height);

		font = d->loadFont("BEACHTYP.TTF", 50.0f);
	}

	d->drawImage(back[0], 0, 0);
	d->drawImage(back[1], 640, 0);

	d->drawText("MissionBriefing:", font, 100, 50, 1100.0f, 1.0f, 0.0f, 0.0f, 0.0f);
	d->drawText("Preliminary scans indicate the presence of a large number of unknown fungi in this cavern.", font, 100, 120, 1100.0f, 1.0f, 0.0f, 0.0f, 0.0f);
	d->drawText("We need you to take the exploration vehicle and take detailed readings of each fungal type.", font, 100, 260, 1100.0f, 1.0f, 0.0f, 0.0f, 0.0f);
	d->drawText("Be careful; our analysis shows significant sporal activity in the cavern.  We do not know what the effect of contact with these spores will be.", font, 100, 450, 1100.0f, 1.0f, 0.0f, 0.0f, 0.0f);
	d->drawText("(space)", font, 585, 680, 1100.0f, 1.0f, 0.0f, 0.0f, 0.0f);
}

//------------------------------------------------------------------------------
void StoryScreen::keyDown(const string& action, const SDL_keysym& keyPressed)
{
	if(action == "Escape")
		nextState("TitleScreen");
	else if(action == "Action")
	{
		if(easyMode)
			nextState("GamePlay", "easy");
		else
			nextState("GamePlay");
	}
}
