//	TitleScreen.cpp - The title screen game state.
//  ----------------------------------------------------------------------------
//	This file is part of 'GameTemplate', template code for a game.
//	Copyright (C) 2010  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#include "TitleScreen.h"
#include "NiallsDrawingLib/Drawer.h"
#include "NiallsDrawingLib/ImageLoader.h"
#include "Images.h"
#include "Random.h"

using namespace std;

//------------------------------------------------------------------------------
uint32_t TitleScreen::back[2] = {0, 0};
uint32_t TitleScreen::title[2] = {0, 0};
uint32_t TitleScreen::font = 0;
bool TitleScreen::easyMode = false;

//------------------------------------------------------------------------------
TitleScreen::TitleScreen(Application *app):
GameState(app),
menu(0)
{
	
}

//------------------------------------------------------------------------------
TitleScreen::~TitleScreen()
{
	
}

//------------------------------------------------------------------------------
void TitleScreen::draw(Drawer *d)
{
	float x, y;

	if(!font)
	{
		ImageLoader imLoad;
		ImageData data;

		data = imLoad.loadImage(Images::back1_jpg, Images::back1_jpgSize);
		back[0] = d->loadImage(data.data, data.width, data.height);

		data = imLoad.loadImage(Images::back2_jpg, Images::back2_jpgSize);
		back[1] = d->loadImage(data.data, data.width, data.height);

		data = imLoad.loadImage(Images::title1_png, Images::title1_pngSize);
		title[0] = d->loadImage(data.data, data.width, data.height);

		data = imLoad.loadImage(Images::title2_png, Images::title2_pngSize);
		title[1] = d->loadImage(data.data, data.width, data.height);

		font = d->loadFont("BEACHTYP.TTF", 64.0f);
	}

	d->drawImage(back[0], 0, 0);
	d->drawImage(back[1], 640, 0);
	d->drawImage(title[0], 0, 0);
	d->drawImage(title[1], 640, 0);

	//Draw the menu.
	x = 140.0f;
	y = 472.0f;
	if(menu == 0)
	{
		x += (Random::getGlobal().getRandomFloat() * 8.0f)-4.0f;
		y += (Random::getGlobal().getRandomFloat() * 8.0f)-4.0f;
	}
	d->drawText("Enter the Lair", font, x, y, 512.0f, 1.0f, 0.0f, 0.0f, 0.0f);
	x = 140.0f;
	y = 535.0f;
	if(menu == 1)
	{
		x += (Random::getGlobal().getRandomFloat() * 8.0f)-4.0f;
		y += (Random::getGlobal().getRandomFloat() * 8.0f)-4.0f;
	}
	if(easyMode)
		d->drawText("Difficulty: Lo", font, x, y, 512.0f, 1.0f, 0.0f, 0.0f, 0.0f);
	else
		d->drawText("Difficulty: Hi", font, x, y, 512.0f, 1.0f, 0.0f, 0.0f, 0.0f);
	x = 140.0f;
	y = 598.0f;
	if(menu == 2)
	{
		x += (Random::getGlobal().getRandomFloat() * 8.0f)-4.0f;
		y += (Random::getGlobal().getRandomFloat() * 8.0f)-4.0f;
	}
	d->drawText("Quit", font, x, y, 512.0f, 1.0f, 0.0f, 0.0f, 0.0f);
}

//------------------------------------------------------------------------------
void TitleScreen::keyDown(const string& action, const SDL_keysym& keyPressed)
{
	if(action == "Escape")
		quit();
	else if(action == "Action")
	{
		if(menu == 0)
		{
			if(easyMode)
				nextState("StoryScreen", "easy");
			else
				nextState("StoryScreen");
		}
		else if(menu == 1)
			easyMode = !easyMode;
		else if(menu == 2)
			quit();
	}
	else if(action == "P1Up")
	{
		if(menu == 0)
			menu = 2;
		else
			--menu;
	}
	else if(action == "P1Down")
	{
		if(menu == 2)
			menu = 0;
		else
			++menu;
	}
	else if(action == "P1Left")
	{
		if(menu == 1)
			easyMode = !easyMode;
	}
	else if(action == "P1Right")
	{
		if(menu == 1)
			easyMode = !easyMode;
	}
}
