//	Weapon.cpp - A toadstool which fires bullets.
//  ----------------------------------------------------------------------------
//	This file is part of 'GameTemplate', template code for a game.
//	Copyright (C) 2010  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#include "Weapon.h"
#include "NiallsDrawingLib/Drawer.h"
#include "NiallsDrawingLib/ImageLoader.h"
#include "Images.h"
#include "Random.h"
#include "GamePlay.h"

#include <cmath>

//------------------------------------------------------------------------------
uint32_t Weapon::image = 0;

//------------------------------------------------------------------------------
Weapon::Weapon():
xPos(0.0f),
yPos(0.0f),
squash(0.0f)
{
	if(Random::getGlobal().getRandomFloat() < 0.5f)
		rotation = Random::getGlobal().getRandomFloat() * 360.0f;
	else
		rotation = (Random::getGlobal().getRandomFloat() * 90.0f) + 225.0f;
	xPlayer = 30.0f;
	xPlayer += -sinf((rotation/360.0f) * 6.283185f) * 65.0f;
	yPlayer = 7.0f;
	yPlayer += cosf((rotation/360.0f) * 6.283185f) * 36.0f;

	bulletCount = 30;
	bulletCount += (int)(Random::getGlobal().getRandomFloat()*29.9999f);
}

//------------------------------------------------------------------------------
Weapon::~Weapon()
{
	
}

//------------------------------------------------------------------------------
void Weapon::move(GamePlay *gp, float pX, float pY)
{
	xPos = pX + xPlayer;
	yPos = pY + yPlayer;

	--bulletCount;
	if(bulletCount <= 0)
	{
		gp->addBullet(xPos, yPos, rotation);

		bulletCount = 30;
		bulletCount += (int)(Random::getGlobal().getRandomFloat()*29.9999f);

		squash = 0.5f;
	}

	if(squash < 1.0f)
		squash += 0.05f;
}

//------------------------------------------------------------------------------
void Weapon::draw(Drawer *d)
{
	if(!image)
	{
		ImageLoader imLoad;
		ImageData data;

		data = imLoad.loadImage(Images::weapontoadstool_png, Images::weapontoadstool_pngSize);
		image = d->loadImage(data.data, data.width, data.height);
	}

	d->drawImageRot(image, xPos, yPos, rotation, 17.5f, 21.5f, 1.0f, squash);
}
