//	Weapon.h - A toadstool which fires bullets.
//  ----------------------------------------------------------------------------
//	This file is part of 'GameTemplate', template code for a game.
//	Copyright (C) 2010  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifndef WEAPON_H_
#define WEAPON_H_

#include <stdint.h>

class Drawer;
class GamePlay;

///	A toadstool which fires bullets.
class Weapon
{
  public:
	///	Constructor.
	Weapon();
	///	Destructor.
	~Weapon();

	///	Moves the weapon, fires it.
	void move(GamePlay *gp, float pX, float pY);
	///	Draws the weapon.
	void draw(Drawer *d);
  private:
	///	The weapon's image.
	static uint32_t image;

	///	The weapon's position on screen.
	float xPos;
	///	The weapon's position on screen.
	float yPos;
	///	The weapon's position relative to the player.
	float xPlayer;
	///	The weapon's position relative to the player.
	float yPlayer;
	///	The weapon's rotation.
	float rotation;
	///	Used to determine when to fire a bullet.
	int bulletCount;

	///	Squashes the toadstool when it fires.
	float squash;
};

#endif
