//	Button.cpp - A simple (trigger-style) button.
//  ----------------------------------------------------------------------------
//	This file is part of 'GameTemplate', a game.
//	Copyright (C) 2010  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#include "Button.h"
#include "NiallsDrawingLib/Drawer.h"
#include "NiallsDrawingLib/ImageLoader.h"
#include "MouseCursor.h"

//------------------------------------------------------------------------------
Button::Button(const char *imageUpData, uint32_t imageUpSize,
			   const char *imageDownData, uint32_t imageDownSize):
Widget(),
TriggerBroadcaster(),
up(0),
down(0),
mouseIsDown(false),
mouseIsOver(false),
upData(imageUpData),
upSize(imageUpSize),
downData(imageDownData),
downSize(imageDownSize)
{
	
}

//------------------------------------------------------------------------------
Button::~Button()
{
	
}

//------------------------------------------------------------------------------
void Button::draw(Drawer *d)
{
	if(!up && upData)
	{
		ImageData data;
		ImageLoader loader;

		data = loader.loadImage(upData, upSize);
		up = d->loadImage(data.data, data.width, data.height);

		data = loader.loadImage(downData, downSize);
		down = d->loadImage(data.data, data.width, data.height);
	}

	if(up)
	{
		if(mouseIsDown)
			d->drawImage(down, getXPos(), getYPos());
		else
			d->drawImage(up, getXPos(), getYPos());
	}
}

//------------------------------------------------------------------------------
void Button::mouseMove(float x, float y)
{
	mouseIsOver = true;
	MouseCursor::getInstance().setImage(true);
}

//------------------------------------------------------------------------------
void Button::mouseButton(bool val, float x, float y)
{
	if(val)
	{
		mouseIsDown = true;
		callTriggerCallbacks(this, true);
	}
	else
		mouseIsDown = false;
}

//------------------------------------------------------------------------------
void Button::mouseLeave(float x, float y)
{
	if(mouseIsOver)
	{
		mouseIsOver = false;
		MouseCursor::getInstance().setImage(false);
	}
	mouseIsDown = false;
}
