//	Button.h - A simple (trigger-style) button.
//  ----------------------------------------------------------------------------
//	This file is part of 'GameTemplate', a game.
//	Copyright (C) 2010  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifndef BUTTON_H_
#define BUTTON_H_

#include "Widget.h"
#include "Callbacks.h"

#include <stdint.h>

///	A simple (trigger-style) button.
class Button : public Widget,
			   public TriggerBroadcaster
{
  public:
	///	Constructor.
	Button(const char *imageUpData = 0, uint32_t imageUpSize = 0,
		   const char *imageDownData = 0, uint32_t imageDownSize = 0);
	///	Destructor.
	~Button();

	///	Draws the button.
	void draw(Drawer *d);

	///	Called when the mouse moves within this widget's bounds.
	void mouseMove(float x, float y);
	///	Called when a mouse button is clicked or released.
	void mouseButton(bool val, float x, float y);
	///	Called when the mouse is outside the widget's bounds.
	void mouseLeave(float x, float y);
  private:
	///	The button's up image.
	uint32_t up;
	///	The button's down image.
	uint32_t down;

	///	Whether the mouse button is currently down or not.
	bool mouseIsDown;
	///	If the mouse is over the button.
	bool mouseIsOver;

	///	The button's up image data.
	const char * upData;
	///	The button's up image data size.
	uint32_t upSize;
	///	The button's down image data.
	const char * downData;
	///	The button's down image data size.
	uint32_t downSize;
};

#endif
