//	GradientBackground.h - Simple gradient background widget container.
//  ----------------------------------------------------------------------------
//	This file is part of 'GameTemplate', a game.
//	Copyright (C) 2010  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifndef GRADIENTBACKGROUND_H_
#define GRADIENTBACKGROUND_H_

#include "Widget.h"

#include <stdint.h>

///	Simple gradient background widget container.
class GradientBackground : public Widget
{
  public:
	///	Constructor.
	GradientBackground(uint8_t r1,
					   uint8_t g1,
					   uint8_t b1,
					   uint8_t r2,
					   uint8_t g2,
					   uint8_t b2);
	///	Destructor.
	~GradientBackground();

	///	Draws the gradient.
	void draw(Drawer *d);

	///	Called when the mouse moves within this widget's bounds
	void mouseMove(float x, float y);
	///	Called when a mouse button is clicked or released.
	void mouseButton(bool val, float x, float y);
  private:
	///	The gradient top colour.
	uint8_t red1;
	///	The gradient top colour.
	uint8_t green1;
	///	The gradient top colour.
	uint8_t blue1;
	///	The gradient bottom colour.
	uint8_t red2;
	///	The gradient bottom colour.
	uint8_t green2;
	///	The gradient bottom colour.
	uint8_t blue2;
};

#endif
