//	RadioButtons.h - Basic (vertical) radio buttons widget.
//  ----------------------------------------------------------------------------
//	This file is part of 'GameTemplate', a game.
//	Copyright (C) 2010  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifndef RADIOBUTTONS_H_
#define RADIOBUTTONS_H_

#include "Widget.h"
#include "Callbacks.h"

#include <stdint.h>

///	Basic (vertical) radio buttons widget.
class RadioButtons : public Widget,
					 public ChangeBroadcaster
{
  public:
	///	Constructor.
	RadioButtons(const char *imageUpData, uint32_t imageUpSize,
			     const char *imageDownData, uint32_t imageDownSize,
				 int num, float height);
	///	Destructor.
	~RadioButtons();

	///	Draws the button.
	void draw(Drawer *d);

	///	Called when the mouse moves within this widget's bounds.
	void mouseMove(float x, float y);
	///	Called when a mouse button is clicked or released.
	void mouseButton(bool val, float x, float y);
	///	Called when the mouse is outside the widget's bounds.
	void mouseLeave(float x, float y);

	///	Sets which button is currently selected.
	void setValue(int val);
  private:
	///	The button's up image.
	uint32_t up;
	///	The button's down image.
	uint32_t down;
	///	The height of a button.
	float buttonHeight;

	///	The number of buttons.
	int numButtons;
	///	The currently-selected button.
	int value;

	///	Whether the mouse button is currently down or not.
	bool mouseIsDown;
	///	If the mouse is over the button.
	bool mouseIsOver;

	///	The button's up image data.
	const char * upData;
	///	The button's up image data size.
	uint32_t upSize;
	///	The button's down image data.
	const char * downData;
	///	The button's down image data size.
	uint32_t downSize;
};

#endif
